@@ -9,10 +9,12 @@ struct nanotodon_config {
 	char root_dir[256];
 	char dot_token[256];
 	char dot_domain[256];
+
+	char cache_dir[256];
 };
 
-int nano_config_init(struct nanotodon_config *config);
+int nano_config_init(struct nanotodon_config *);
 
-int nano_config_app_token_filename(struct nanotodon_config *config, const char* domain, char *buf, size_t buf_length);
+int nano_config_app_token_filename(struct nanotodon_config *, const char *, char *, size_t);
 
 #endif
