@@ -12,6 +12,7 @@
 #define SJSON_IMPLEMENT
 #include "sjson.h"
 
+#include "nanotodon.h"
 #include "config.h"
 #include "messages.h"
 #include "sbuf.h"
@@ -19,47 +20,47 @@
 #include "utils.h"
 #include "sixel.h"
 
-char *streaming_json = NULL;
+static char *streaming_json = NULL;
 
 #define URI_STREAM "api/v1/streaming/"
 #define URI_TIMELINE "api/v1/timelines/"
 
-char *selected_stream = "user";
-char *selected_timeline = "home";
-char append_timeline[64];
-int limit_timeline = 20;
+static const char *selected_stream = "user";
+static const char *selected_timeline = "home";
+static char append_timeline[64];
+static int limit_timeline = 20;
 
 #define CURL_USERAGENT "curl/" LIBCURL_VERSION
 
-pthread_mutex_t prompt_mutex;
-int prompt_notify = 0;
+static pthread_mutex_t prompt_mutex;
+static int prompt_notify = 0;
 
 // ストリーミングを受信する関数のポインタ
-void (*streaming_received_handler)(void);
+static void (*streaming_received_handler)(void);
 
 // 受信したストリーミングを処理する関数のポインタ
-void (*stream_event_handler)(sbctx_t *sbctx, struct sjson_node *);
+static void (*stream_event_handler)(struct sjson_node *);
 
 // インスタンスにクライアントを登録する
-void do_create_client(char *, char *);
+static void do_create_client(char *, char *);
 
 // Timelineの受信
-void get_timeline(void);
+static void get_timeline(void);
 
 // 承認コードを使ったOAuth処理
-void do_oauth(char *code, char *ck, char *cs);
+static void do_oauth(char *, char *, char *);
 
 // Tootを行う
-void do_toot(char *);
+static void do_toot(char *);
 
 // ストリーミングでのToot受信処理,stream_event_handlerへ代入
-void stream_event_update(sbctx_t *sbctx, struct sjson_node *);
+static void stream_event_update(struct sjson_node *);
 
 // ストリーミングでの通知受信処理,stream_event_handlerへ代入
-void stream_event_notify(sbctx_t *sbctx, struct sjson_node *);
+static void stream_event_notify(struct sjson_node *);
 
 // アクセストークン文字列
-char access_token[256];
+static char access_token[256];
 
 // ドメイン文字列
 char domain_string[256];
@@ -68,8 +69,8 @@ char domain_string[256];
 struct nanotodon_config config;
 
 int monoflag = 0;
-int hidlckflag = 1;
-int noemojiflag = 0;
+static int hidlckflag = 1;
+static int noemojiflag = 0;
 
 // curlから呼び出されるストリーミング受信関数
 static size_t streaming_callback(void* ptr, size_t size, size_t nmemb, void* data) {
@@ -105,7 +106,7 @@ static size_t streaming_callback(void* ptr, size_t size, size_t nmemb, void* dat
 }
 
 // ストリーミングでの通知受信処理,stream_event_handlerへ代入
-void stream_event_notify(sbctx_t *sbctx, sjson_node *jobj_from_string)
+static void stream_event_notify(sjson_node *jobj_from_string)
 {
 	struct sjson_node *notify_type, *screen_name, *display_name, *status;
 	const char *dname;
@@ -117,6 +118,11 @@ void stream_event_notify(sbctx_t *sbctx, sjson_node *jobj_from_string)
 
 	putchar('\a');
 
+	sbctx_t sb;
+	sbctx_t *sbctx = &sb;
+
+	ninitbuf(&sb);
+
 	// 通知種別を表示に流用するので先頭を大文字化
 	char *t = strdup(notify_type->string_);
 	t[0] = toupper((int)(unsigned char)t[0]);
@@ -144,13 +150,14 @@ void stream_event_notify(sbctx_t *sbctx, sjson_node *jobj_from_string)
 
 	type = status->tag;
 
+	nflushcache(&sb);
+	squeue_enqueue(sb);
+
 	// 通知対象のTootを表示,Follow通知だとtypeがNULLになる
 	if(type != SJSON_NULL && exist_status) {
-		stream_event_update(sbctx, status);
+		stream_event_update(status);
 	}
 
-	naddstr(sbctx, "\n");
-
 	//wrefresh(scr);
 
 	/*wmove(pad, pad_x, pad_y);
@@ -159,7 +166,7 @@ void stream_event_notify(sbctx_t *sbctx, sjson_node *jobj_from_string)
 
 // ストリーミングでのToot受信処理,stream_event_handlerへ代入
 #define DATEBUFLEN	40
-void stream_event_update(sbctx_t *sbctx, struct sjson_node *jobj_from_string)
+static void stream_event_update(struct sjson_node *jobj_from_string)
 {
 	struct sjson_node *content, *screen_name, *display_name, *reblog, *visibility;
 	const char *sname, *dname, *vstr;
@@ -208,27 +215,52 @@ void stream_event_update(sbctx_t *sbctx, struct sjson_node *jobj_from_string)
 
 	// ブーストで回ってきた場合はその旨を表示
 	if(type != SJSON_NULL) {
-		nattron(sbctx,  COLOR_PAIR(3));
-		if(!noemojiflag) naddstr(sbctx,  "🔃 ");
-		naddstr(sbctx,  "Reblog by ");
-		naddstr(sbctx,  sname);
+		sbctx_t sb_reb;
+		sbctx_t *sbctx_reb = &sb_reb;
+
+		ninitbuf(&sb_reb);
+
+		nattron(sbctx_reb,  COLOR_PAIR(3));
+		if(!noemojiflag) naddstr(sbctx_reb,  "🔃 ");
+		naddstr(sbctx_reb,  "Reblog by ");
+		naddstr(sbctx_reb,  sname);
 		// dname(表示名)が空の場合は括弧を表示しない
 		if (dname[0] != '\0') {
-			naddstr(sbctx,  " (");
-			naddstr(sbctx,  dname);
-			naddstr(sbctx,  ")");
+			naddstr(sbctx_reb,  " (");
+			naddstr(sbctx_reb,  dname);
+			naddstr(sbctx_reb,  ")");
 		}
-		naddstr(sbctx,  "\n");
-		nattroff(sbctx,  COLOR_PAIR(3));
-		stream_event_update(sbctx, reblog);
+		naddstr(sbctx_reb,  "\n");
+		nattroff(sbctx_reb,  COLOR_PAIR(3));
+
+		nflushcache(&sb_reb);
+		squeue_enqueue(sb_reb);
+
+		stream_event_update(reblog);
 		return;
 	}
 
 #ifdef USE_SIXEL
-	print_picture(sbctx, avatar->string_, SIXEL_MUL_ICO);
-	naddstr(sbctx, "\n");
+	sbctx_t sb_avt;
+	sbctx_t *sbctx_avt = &sb_avt;
+
+	ninitbuf(&sb_avt);
+
+	print_picture(sbctx_avt, avatar->string_, SIXEL_MUL_ICO);
+
+	// アイコン右側にカーソル移動
+	move_cursor_to_avatar(sbctx_avt);
+
+	nflushcache(&sb_avt);
+	squeue_enqueue(sb_avt);
+	//naddstr(sbctx, "\n");
 #endif
 
+	sbctx_t sb;
+	sbctx_t *sbctx = &sb;
+
+	ninitbuf(&sb);
+
 	// 誰からか[ screen_name(display_name) ]を表示
 	nattron(sbctx,  COLOR_PAIR(1)|A_BOLD);
 	naddstr(sbctx,  sname);
@@ -332,6 +364,9 @@ void stream_event_update(sbctx_t *sbctx, struct sjson_node *jobj_from_string)
 
 	naddstr(sbctx,  "\n");
 
+	nflushcache(&sb);
+	squeue_enqueue(sb);
+
 	// 添付メディアのURL表示
 	struct sjson_node *media_attachments;
 
@@ -339,25 +374,38 @@ void stream_event_update(sbctx_t *sbctx, struct sjson_node *jobj_from_string)
 
 	if(media_attachments->tag == SJSON_ARRAY) {
 		for (int i = 0; i < sjson_child_count(media_attachments); ++i) {
+			sbctx_t sb_att;
+			sbctx_t *sbctx_att = &sb_att;
+
+			ninitbuf(&sb_att);
+
 			struct sjson_node *obj = sjson_find_element(media_attachments, i);
 			struct sjson_node *url;
 			read_json_fom_path(obj, "url", &url);
 			if(url->tag == SJSON_STRING) {
-				naddstr(sbctx,  noemojiflag ? "<LINK>" : "🔗");
-				naddstr(sbctx,  url->string_);
-				naddstr(sbctx,  "\n");
+				naddstr(sbctx_att,  noemojiflag ? "<LINK>" : "🔗");
+				naddstr(sbctx_att,  url->string_);
+				naddstr(sbctx_att,  "\n");
 #ifdef USE_SIXEL
 				struct sjson_node *type;
 				read_json_fom_path(obj, "type", &type);
 				if(!strcmp(type->string_, "image")) {
-					print_picture(sbctx, url->string_, SIXEL_MUL_PIC | fnsfw);
-					naddstr(sbctx,  "\n");
+					print_picture(sbctx_att, url->string_, SIXEL_MUL_PIC | fnsfw);
+					naddstr(sbctx_att,  "\n");
 				}
 #endif
 			}
+
+			nflushcache(&sb_att);
+			squeue_enqueue(sb_att);
 		}
 	}
 
+	sbctx_t sb_end;
+	sbctx_t *sbctx_end = &sb_end;
+
+	ninitbuf(&sb_end);
+
 	// 投稿アプリ名表示
 	struct sjson_node *application_name;
 	int exist_appname = read_json_fom_path(jobj_from_string, "application/name", &application_name);
@@ -367,19 +415,23 @@ void stream_event_update(sbctx_t *sbctx, struct sjson_node *jobj_from_string)
 		type = application_name->tag;
 
 		if(type != SJSON_NULL) {
-			naddstr(sbctx,  " - ");
+			naddstr(sbctx_end,  " - ");
 
-			nattron(sbctx,  COLOR_PAIR(1));
-			naddstr(sbctx,  "via ");
-			nattroff(sbctx,  COLOR_PAIR(1));
-			nattron(sbctx,  COLOR_PAIR(2));
-			naddstr(sbctx,  application_name->string_);
-			naddstr(sbctx,  "\n");
-			nattroff(sbctx,  COLOR_PAIR(2));
+			nattron(sbctx_end,  COLOR_PAIR(1));
+			naddstr(sbctx_end,  "via ");
+			nattroff(sbctx_end,  COLOR_PAIR(1));
+			nattron(sbctx_end,  COLOR_PAIR(2));
+			naddstr(sbctx_end,  application_name->string_);
+			naddstr(sbctx_end,  "\n");
+			nattroff(sbctx_end,  COLOR_PAIR(2));
 		}
 	}
 
-	naddstr(sbctx,  "\n");
+	naddstr(sbctx_end, "\n\n");
+
+	nflushcache(&sb_end);
+	squeue_enqueue(sb_end);
+
 	//wrefresh(scr);
 
 	/*wmove(pad, pad_x, pad_y);
@@ -415,13 +467,13 @@ static void streaming_received(void)
 			sjson_context* ctx = sjson_create_context(0, 0, NULL);
 			struct sjson_node *jobj_from_string = sjson_decode(ctx, streaming_json + 6);
 
-			sbctx_t sb;
-			ninitbuf(&sb);
+			//sbctx_t sb;
+			//ninitbuf(&sb);
 
-			stream_event_handler(&sb, jobj_from_string);
+			stream_event_handler(jobj_from_string);
 
-			nflushcache(&sb);
-			squeue_enqueue(sb);
+			//nflushcache(&sb);
+			//squeue_enqueue(sb);
 
 			sjson_destroy_context(ctx);
 			stream_event_handler = NULL;
@@ -501,7 +553,7 @@ static void *prompt_thread_func(void *param)
 }
 
 // インスタンスにクライアントを登録する
-void do_create_client(char *domain, char *dot_ckcs)
+static void do_create_client(char *domain, char *dot_ckcs)
 {
 	CURLcode ret;
 	CURL *hnd;
@@ -554,7 +606,7 @@ void do_create_client(char *domain, char *dot_ckcs)
 }
 
 // 承認コードを使ったOAuth処理
-void do_oauth(char *code, char *ck, char *cs)
+static void do_oauth(char *code, char *ck, char *cs)
 {
 	char fields[512];
 	sprintf(fields, "client_id=%s&client_secret=%s&grant_type=authorization_code&code=%s&scope=read%%20write%%20follow", ck, cs, code);
@@ -612,7 +664,7 @@ void do_oauth(char *code, char *ck, char *cs)
 }
 
 // Tootを行う
-void do_toot(char *s)
+static void do_toot(char *s)
 {
 	CURLcode ret;
 	CURL *hnd;
@@ -702,7 +754,7 @@ static size_t htl_callback(void* ptr, size_t size, size_t nmemb, void* data) {
 }
 
 // Timelineの受信
-void get_timeline(void)
+static void get_timeline(void)
 {
 	CURLcode ret;
 	CURL *hnd;
@@ -750,13 +802,13 @@ void get_timeline(void)
 		for (int i = sjson_child_count(jobj_from_string) - 1; i >= 0; i--) {
 			struct sjson_node *obj = sjson_find_element(jobj_from_string, i);
 
-			sbctx_t sb;
-			ninitbuf(&sb);
+			//sbctx_t sb;
+			//ninitbuf(&sb);
 
-			stream_event_update(&sb, obj);
+			stream_event_update(obj);
 
-			nflushcache(&sb);
-			squeue_enqueue(sb);
+			//nflushcache(&sb);
+			//squeue_enqueue(sb);
 		}
 	}
 
